@@ -34,10 +34,10 @@
 //   - checkbox buttons look fine without Caption
 //   - PickerButton could use a larger font
 // - add reset button to restore default settings
-// - set default selector in interval picker dialog
 // - check settings dialog for object/memory leaks
 // - check return code from g_timeout_add_seconds/g_signal_connect
-// - set .so version
+// - does g_source_remove destroy the source or does it leak?
+// - draw nice icons
 // - support multiple instances
 
 
@@ -80,7 +80,7 @@
 // TODO: find out how to get debug logs from hildon-desktop
 #define g_debug g_message
 
-#define USER_AGENT_VERSION_STRING (debug version)
+#define USER_AGENT_VERSION_STRING "(debug version)"
 
 #else
 
@@ -88,7 +88,7 @@
 // (compiler should optimize it away)
 #define g_debug(fmt...) do { if (0) { g_message(fmt); } } while (0)
 
-#define USER_AGENT_VERSION_STRING (some version number)
+#define USER_AGENT_VERSION_STRING "(some version number)"
 
 #endif // DEBUG
 
@@ -113,7 +113,7 @@ stop_update_timer(CCCHHDoorIsDesktopWidget *self)
 {
 	// stop timer if it was running
 	if (self->timeout_handler) {
-		g_debug("ccchh-dooris-widget: stopping update timer");
+		g_debug(WIDGET_NAME": stopping update timer");
 		g_source_remove (self->timeout_handler);
 		self->timeout_handler = 0;
 		return TRUE;
@@ -130,12 +130,12 @@ static inline gboolean
 start_update_timer(CCCHHDoorIsDesktopWidget *self)
 {
 	if (!self->timeout_handler) {
-		g_debug("ccchh-dooris-widget: starting update timer");
+		g_debug(WIDGET_NAME": starting update timer");
 		if (self->update_interval < UPDATE_INTERVAL_MIN) {
-			g_warning("ccchh-dooris-widget: self->update_interval < UPDATE_INTERVAL_MIN, maybe a bug?");
+			g_warning(WIDGET_NAME": self->update_interval < UPDATE_INTERVAL_MIN, maybe a bug?");
 			self->update_interval = UPDATE_INTERVAL_MIN;
 		} else if (self->update_interval > UPDATE_INTERVAL_MAX) {
-			g_warning("ccchh-dooris-widget: self->update_interval > UPDATE_INTERVAL_MAX, maybe a bug?");
+			g_warning(WIDGET_NAME": self->update_interval > UPDATE_INTERVAL_MAX, maybe a bug?");
 			self->update_interval = UPDATE_INTERVAL_MAX;
 		}
 		self->timeout_handler = g_timeout_add_seconds (self->update_interval*60, ccchh_dooris_desktop_widget_on_timeout, self);
@@ -160,7 +160,7 @@ install_connection_handler(CCCHHDoorIsDesktopWidget *self)
 			G_CALLBACK (ccchh_dooris_desktop_widget_connection_event), self);
 		/* Set automatic events */
 		g_object_set (self->connection, "automatic-connection-events", TRUE, NULL);
-		g_debug("ccchh-dooris-widget: connection monitoring enabled");
+		g_debug(WIDGET_NAME": connection monitoring enabled");
 		return TRUE;
 	}
 
@@ -178,7 +178,7 @@ remove_connection_handler(CCCHHDoorIsDesktopWidget *self)
 		g_object_set (self->connection, "automatic-connection-events", FALSE, NULL);
 		g_signal_handler_disconnect (self->connection, self->connection_handler);
 		self->connection_handler = 0;
-		g_debug("ccchh-dooris-widget: connection monitoring disabled");
+		g_debug(WIDGET_NAME": connection monitoring disabled");
 		return TRUE;
 	}
 
@@ -195,13 +195,13 @@ load_settings(CCCHHDoorIsDesktopWidget *self)
 
 	error = NULL;
 
-	g_debug("ccchh-dooris-widget: load_settings()");
+	g_debug(WIDGET_NAME": load_settings()");
 
 	gchar *strval = gconf_client_get_string(self->gconf_client,
 		GCONF_DIR"/update_url", &error);
 
 	if (error) {
-		g_warning("ccchh-dooris-widget: failed to get configuration value update_url: %s",
+		g_warning(WIDGET_NAME": failed to get configuration value update_url: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -212,7 +212,7 @@ load_settings(CCCHHDoorIsDesktopWidget *self)
 		}
 
 		self->update_url = gnome_vfs_make_uri_from_input(strval);
-		g_debug("ccchh-dooris-widget: load_settings: url = %s", self->update_url);
+		g_debug(WIDGET_NAME": load_settings: url = %s", self->update_url);
 
 		g_free(strval);
 		strval = NULL;
@@ -222,33 +222,33 @@ load_settings(CCCHHDoorIsDesktopWidget *self)
 		GCONF_DIR"/update_interval", &error);
 
 	if (error) {
-		g_warning("ccchh-dooris-widget: failed to get configuration value update_interval: %s",
+		g_warning(WIDGET_NAME": failed to get configuration value update_interval: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
 	} else if (intval) {
 		self->update_interval = intval;
 		if (self->update_interval < UPDATE_INTERVAL_MIN) {
-			g_warning("ccchh-dooris-widget: self->update_interval < UPDATE_INTERVAL_MIN, maybe a bug?");
+			g_warning(WIDGET_NAME": self->update_interval < UPDATE_INTERVAL_MIN, maybe a bug?");
 			self->update_interval = UPDATE_INTERVAL_MIN;
 		} else if (self->update_interval > UPDATE_INTERVAL_MAX) {
-			g_warning("ccchh-dooris-widget: self->update_interval > UPDATE_INTERVAL_MAX, maybe a bug?");
+			g_warning(WIDGET_NAME": self->update_interval > UPDATE_INTERVAL_MAX, maybe a bug?");
 			self->update_interval = UPDATE_INTERVAL_MAX;
 		}
-		g_debug("ccchh-dooris-widget: load_settings: update = %ld", (long)self->update_interval);
+		g_debug(WIDGET_NAME": load_settings: update = %ld", (long)self->update_interval);
 	}
 
 	gboolean boolval = gconf_client_get_bool(self->gconf_client,
 		GCONF_DIR"/notify_enabled", &error);
 
 	if (error) {
-		g_warning("ccchh-dooris-widget: failed to get configuration value notify_enabled: %s",
+		g_warning(WIDGET_NAME": failed to get configuration value notify_enabled: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
 	} else {
 		self->notify_enabled = boolval;
-		g_debug("ccchh-dooris-widget: load_settings: notify = %d", self->notify_enabled);
+		g_debug(WIDGET_NAME": load_settings: notify = %d", self->notify_enabled);
 	}
 
 
@@ -256,26 +256,26 @@ load_settings(CCCHHDoorIsDesktopWidget *self)
 		GCONF_DIR"/use_connection", &error);
 
 	if (error) {
-		g_warning("ccchh-dooris-widget: failed to get configuration value use_connection: %s",
+		g_warning(WIDGET_NAME": failed to get configuration value use_connection: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
 	} else {
 		self->use_connection = boolval;
-		g_debug("ccchh-dooris-widget: load_settings: use_connection = %d", self->use_connection);
+		g_debug(WIDGET_NAME": load_settings: use_connection = %d", self->use_connection);
 	}
 
 	boolval = gconf_client_get_bool(self->gconf_client,
 		GCONF_DIR"/force_connection", &error);
 
 	if (error) {
-		g_warning("ccchh-dooris-widget: failed to get configuration value force_connection: %s",
+		g_warning(WIDGET_NAME": failed to get configuration value force_connection: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
 	} else {
 		self->force_connection = boolval;
-		g_debug("ccchh-dooris-widget: load_settings: force_connection = %d", self->force_connection);
+		g_debug(WIDGET_NAME": load_settings: force_connection = %d", self->force_connection);
 	}
 }
 
@@ -287,12 +287,12 @@ save_settings(CCCHHDoorIsDesktopWidget *self)
 
 	error = NULL;
 
-	g_debug("ccchh-dooris-widget: save_settings()");
+	g_debug(WIDGET_NAME": save_settings()");
 
 	if (!gconf_client_set_string(self->gconf_client,
 		GCONF_DIR"/update_url", self->update_url, &error))
 	{
-		g_warning("ccchh-dooris-widget: failed to set configuration value update_url: %s",
+		g_warning(WIDGET_NAME": failed to set configuration value update_url: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -301,7 +301,7 @@ save_settings(CCCHHDoorIsDesktopWidget *self)
 	if (!gconf_client_set_int(self->gconf_client,
 		GCONF_DIR"/update_interval", self->update_interval, &error))
 	{
-		g_warning("ccchh-dooris-widget: failed to set configuration value update_interval: %s",
+		g_warning(WIDGET_NAME": failed to set configuration value update_interval: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -310,7 +310,7 @@ save_settings(CCCHHDoorIsDesktopWidget *self)
 	if (!gconf_client_set_bool(self->gconf_client,
 		GCONF_DIR"/notify_enabled", self->notify_enabled, &error))
 	{
-		g_warning("ccchh-dooris-widget: failed to set configuration value notify_enabled: %s",
+		g_warning(WIDGET_NAME": failed to set configuration value notify_enabled: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -319,7 +319,7 @@ save_settings(CCCHHDoorIsDesktopWidget *self)
 	if (!gconf_client_set_bool(self->gconf_client,
 		GCONF_DIR"/use_connection", self->use_connection, &error))
 	{
-		g_warning("ccchh-dooris-widget: failed to set configuration value use_connection: %s",
+		g_warning(WIDGET_NAME": failed to set configuration value use_connection: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -328,7 +328,7 @@ save_settings(CCCHHDoorIsDesktopWidget *self)
 	if (!gconf_client_set_bool(self->gconf_client,
 		GCONF_DIR"/force_connection", self->force_connection, &error))
 	{
-		g_warning("ccchh-dooris-widget: failed to set configuration value force_connection: %s",
+		g_warning(WIDGET_NAME": failed to set configuration value force_connection: %s",
 			error->message);
 		g_error_free(error);
 		error = NULL;
@@ -341,10 +341,10 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 {
 //  GtkWidget *widget = GTK_WIDGET(self);
   
-	g_debug("ccchh-dooris-widget: draw()");
+	g_debug(WIDGET_NAME": draw()");
 
 	if (!self->image_current) {
-		g_debug("ccchh-dooris-widget: draw() without image");
+		g_debug(WIDGET_NAME": draw() without image");
 		self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_FNORD);
 	}
 
@@ -362,7 +362,7 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 
 	// if not connected, overlay icon with "disconnected" image
 	if (!self->connected) {
-		g_debug("ccchh-dooris-widget: not connected, overlay image");
+		g_debug(WIDGET_NAME": not connected, overlay image");
 		cairo_surface_t *image_overlay = cairo_image_surface_create_from_png(IMAGE_OVERLAY_DISCONNECTED);
 		cairo_set_source_surface(cr, image_overlay, 5, 5);
 		cairo_paint_with_alpha(cr, self->current_alpha);
@@ -375,6 +375,11 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 		cairo_mask_surface(cr, self->image_current, 5, 5);
 	}
 
+if (!self->timeout_handler) {
+	cairo_set_source_rgba(cr, 1, 0, 0, 0.47);
+	cairo_mask_surface(cr, self->image_current, 5, 5);
+}
+
 	cairo_restore(cr);
 }
 
@@ -385,7 +390,7 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 	time_t timenow, timediff;
 	gchar *text, *ts_text;
 
-	g_debug("ccchh-dooris-widget: show_status_banner()");
+	g_debug(WIDGET_NAME": show_status_banner()");
 
 	time (&timenow);
 
@@ -439,7 +444,7 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 static void
 force_redraw (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: force_redraw()");
+	g_debug(WIDGET_NAME": force_redraw()");
 
 	/* Invalidate the drawing: */
 	GtkWidget *widget = GTK_WIDGET (self);
@@ -498,19 +503,19 @@ fetch_update_unlock (CCCHHDoorIsDesktopWidget *self)
 static void
 fetch_update_start (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: fetch_update_start()");
+	g_debug(WIDGET_NAME": fetch_update_start()");
 
 	if (!self->connected) {
-		g_debug("ccchh-dooris-widget: not connected, not fetching new state");
+		g_debug(WIDGET_NAME": not connected, not fetching new state");
 		return;
 	}
 
 	if (!fetch_update_lock(self)) {
-		g_message("ccchh-dooris-widget: fetch_lock set, not updating");
+		g_message(WIDGET_NAME": fetch_lock set, not updating");
 		return;
 	}
 
-	g_debug("ccchh-dooris-widget: begin update from URL: %s", self->update_url);
+	g_debug(WIDGET_NAME": begin update from URL: %s", self->update_url);
 
 	self->gvfs_timeout_handler = g_timeout_add_seconds (TIMEOUT_CONNECT, fetch_update_cancel_cb, self);
 
@@ -524,9 +529,15 @@ fetch_update_cancel_cb (gpointer data)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
   
-	g_debug("ccchh-dooris-widget: fetch_update_cancel_cb()");
+	g_debug(WIDGET_NAME": fetch_update_cancel_cb()");
 
-	g_warning("ccchh-dooris-widget: I/O timeout, cancelling operation");
+	if (g_source_is_destroyed(g_main_current_source())) {
+		// this shouldn't happen
+		g_debug(WIDGET_NAME": update_cancel: source destroyed");
+		return FALSE;
+	}
+
+	g_warning(WIDGET_NAME": I/O timeout, cancelling operation");
 	gnome_vfs_async_cancel(self->gvfs_handle);
 
 	fetch_update_process(self, DOORIS_FNORD, 0L, 0L);
@@ -542,7 +553,7 @@ fetch_update_async_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
 
-	g_debug("ccchh-dooris-widget: fetch_update_async_open_cb()");
+	g_debug(WIDGET_NAME": fetch_update_async_open_cb()");
 
 	if (self->gvfs_timeout_handler) {
 		g_source_remove (self->gvfs_timeout_handler);
@@ -550,14 +561,14 @@ fetch_update_async_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	}
 
 	if (result != GNOME_VFS_OK) {
-		g_warning("ccchh-dooris-widget: error opening URL: %s", gnome_vfs_result_to_string (result));
+		g_warning(WIDGET_NAME": error opening URL: %s", gnome_vfs_result_to_string (result));
 		fetch_update_process(self, DOORIS_FNORD, 0L, 0L);
 		return;
 	}
 
 	// reuse input buffer, ensure it has at least MAX_HTTP_SIZE+1
 	if (!(self->gvfs_input_buffer = g_try_realloc(self->gvfs_input_buffer, MAX_HTTP_SIZE+1))) {
-		g_warning("ccchh-dooris-widget: failed to allocate input buffer");
+		g_warning(WIDGET_NAME": failed to allocate input buffer");
 		fetch_update_process(self, DOORIS_FNORD, 0L, 0L);
 		return;
 	}
@@ -579,7 +590,7 @@ fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
 
-	g_debug("ccchh-dooris-widget: fetch_update_async_read_cb()");
+	g_debug(WIDGET_NAME": fetch_update_async_read_cb()");
 
 	if (self->gvfs_timeout_handler) {
 		g_source_remove (self->gvfs_timeout_handler);
@@ -587,12 +598,12 @@ fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	}
 
 	if (result != GNOME_VFS_OK) {
-		g_warning("ccchh-dooris-widget: read error: %s", gnome_vfs_result_to_string (result));
+		g_warning(WIDGET_NAME": read error: %s", gnome_vfs_result_to_string (result));
 		fetch_update_process(self, DOORIS_FNORD, 0L, 0L);
 		return;
 	}
 
-	g_debug("ccchh-dooris-widget: read %"GNOME_VFS_SIZE_FORMAT_STR" bytes", bytes_read);
+	g_debug(WIDGET_NAME": read %"GNOME_VFS_SIZE_FORMAT_STR" bytes", bytes_read);
 
 //	self->gvfs_timeout_handler = g_timeout_add_seconds (TIMEOUT_CLOSE, fetch_update_cancel_cb, self);
 
@@ -613,19 +624,19 @@ fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	// first line of body is either "locked" or "unlocked"
 
 	if (!(line = strtok_r(self->gvfs_input_buffer, "\n", &tokctx))) {
-		g_warning("ccchh-dooris-widget: first line of response not found");
+		g_warning(WIDGET_NAME": first line of response not found");
 		fetch_update_process(self, new_state, new_change_ts, new_report_ts);
 		return;
 	}
 
 	if (!strcmp(line, "locked")) {
 		new_state = DOORIS_CLOSED;
-		g_debug("ccchh-dooris-widget: current state: closed");
+		g_debug(WIDGET_NAME": current state: closed");
 	} else if (!strcmp(line, "unlocked")) {
 		new_state = DOORIS_OPEN;
-		g_debug("ccchh-dooris-widget: current state: open");
+		g_debug(WIDGET_NAME": current state: open");
 	} else {
-		g_warning("ccchh-dooris-widget: could not parse response");
+		g_warning(WIDGET_NAME": could not parse response");
 		fetch_update_process(self, new_state, new_change_ts, new_report_ts);
 		return;
 	}
@@ -637,9 +648,9 @@ fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 		ts = strtoul(line, (char **) NULL, 10);
 		if (ts && !errno) {
 			new_report_ts = ts;
-			g_debug("ccchh-dooris-widget: last_report_ts: %lu, errno: %i\n", ts, errno);
+			g_debug(WIDGET_NAME": last_report_ts: %lu, errno: %i\n", ts, errno);
 		} else {
-			g_warning("ccchh-dooris-widget: could not parse last_report_ts");
+			g_warning(WIDGET_NAME": could not parse last_report_ts");
 		}
 
 		// third line of body is last state change timestamp
@@ -649,9 +660,9 @@ fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 			ts = strtoul(line, (char **) NULL, 10);
 			if (ts && !errno) {
 				new_change_ts = ts;
-				g_debug("ccchh-dooris-widget: last_change_ts: %lu, errno: %i\n", ts, errno);
+				g_debug(WIDGET_NAME": last_change_ts: %lu, errno: %i\n", ts, errno);
 			} else {
-				g_warning("ccchh-dooris-widget: could not parse last_change_ts");
+				g_warning(WIDGET_NAME": could not parse last_change_ts");
 			}
 		}
 	}
@@ -667,7 +678,7 @@ fetch_update_async_close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
 
-	g_debug("ccchh-dooris-widget: fetch_update_async_close_cb()");
+	g_debug(WIDGET_NAME": fetch_update_async_close_cb()");
 
 	if (self->gvfs_timeout_handler) {
 		g_source_remove (self->gvfs_timeout_handler);
@@ -675,7 +686,7 @@ fetch_update_async_close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	}
 
 	if (result != GNOME_VFS_OK) {
-		g_debug("ccchh-dooris-widget: error on close: %s", gnome_vfs_result_to_string (result));
+		g_debug(WIDGET_NAME": error on close: %s", gnome_vfs_result_to_string (result));
 		// TODO: what now?
 	}
 }
@@ -686,14 +697,14 @@ static void
 fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 	gulong new_change_ts, gulong new_report_ts)
 {
-	g_debug("ccchh-dooris-widget: fetch_update_process()");
+	g_debug(WIDGET_NAME": fetch_update_process()");
 
 	self->current_state = new_state;
 	self->last_change_ts = new_change_ts;
 	self->last_report_ts = new_report_ts;
 
 	if (new_state == self->last_state) {
-		g_debug("ccchh-dooris-widget: state unchanged");
+		g_debug(WIDGET_NAME": state unchanged");
 
 		if (self->force_banner) {
 			self->force_banner = FALSE;
@@ -714,15 +725,15 @@ fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 	switch (self->current_state) {
 		case DOORIS_OPEN:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_OPEN);
-			g_debug("ccchh-dooris-widget: image_current set to open");
+			g_debug(WIDGET_NAME": image_current set to open");
 			break;
 		case DOORIS_CLOSED:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_CLOSED);
-			g_debug("ccchh-dooris-widget: image_current set to closed");
+			g_debug(WIDGET_NAME": image_current set to closed");
 			break;
 		default:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_FNORD);
-			g_debug("ccchh-dooris-widget: image_current set to fnord");
+			g_debug(WIDGET_NAME": image_current set to fnord");
 			break;
 	}
 
@@ -732,7 +743,7 @@ fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 	if (self->current_state != DOORIS_FNORD && self->current_state != self->last_known_state) {
 
 		self->last_known_state = self->current_state;
-		g_debug("ccchh-dooris-widget: state changed");
+		g_debug(WIDGET_NAME": state changed");
 
 		// state changed: redraw icon
 		force_redraw(self);
@@ -761,11 +772,22 @@ ccchh_dooris_desktop_widget_on_timeout (gpointer data)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
   
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_timeout()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_timeout()");
+
+	if (g_source_is_destroyed(g_main_current_source())) {
+		// this shouldn't happen
+		g_debug(WIDGET_NAME": on_timeout: source destroyed");
+		return FALSE;
+	}
+
 
 	// stop timer when offline
 	// connection event starts it again
 	if (!self->connected) {
+		g_debug(WIDGET_NAME": not connected, stopping update timer");
+// TODO: is this safe? how about remove_source from within the event?
+self->timeout_handler = 0;
+force_redraw(self);
 		return FALSE;
 	}
 
@@ -780,10 +802,10 @@ ccchh_dooris_desktop_widget_expose_event (GtkWidget *widget, GdkEventExpose *eve
 {    
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_expose_event()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_expose_event()");
 
 	if (!self->image_current) {
-		g_debug("ccchh-dooris-widget: expose event without image");
+		g_debug(WIDGET_NAME": expose event without image");
 		self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_FNORD);
 		// no state yet, begin update
 		fetch_update_start(self);
@@ -814,11 +836,11 @@ ccchh_dooris_desktop_widget_on_button_press_event (GtkWidget *widget,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_button_press_event()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_button_press_event()");
  
 	// TODO: do we really need a button lock? fetch_update locks itself now
 	if (!g_static_mutex_trylock(&(self->button_lock))) {
-		g_debug("ccchh-dooris-widget: button_lock set, not updating");
+		g_debug(WIDGET_NAME": button_lock set, not updating");
 		return TRUE;
 	}
 
@@ -836,7 +858,7 @@ ccchh_dooris_desktop_widget_on_button_leave_event (GtkWidget *widget,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_button_leave_event()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_button_leave_event()");
  
 	self->highlighted = FALSE;
 	force_redraw(self);
@@ -854,19 +876,19 @@ ccchh_dooris_desktop_widget_on_button_release_event (GtkWidget *widget,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_button_release_event()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_button_release_event()");
  
 	// request connection from libconic, if offline and
 	// force_connection is enabled
 	// TODO: this does not work immediately, the call to update()
 	// will still see !connected. maybe wait a bit or use a timer event?
 	if (!self->connected && self->force_connection) {
-		g_debug("ccchh-dooris-widget: not connected, requesting connection");
+		g_debug(WIDGET_NAME": not connected, requesting connection");
 		/* Request connection and check for the result */
 		gboolean success = con_ic_connection_connect(self->connection,
 			CON_IC_CONNECT_FLAG_NONE);
 		if (!success) 
-			g_warning("ccchh-dooris-widget: request for connection failed");
+			g_warning(WIDGET_NAME": request for connection failed");
 	}
 
 	self->force_banner = TRUE;
@@ -892,7 +914,7 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (user_data);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_connection_event()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_connection_event()");
 
 	// libconic signalled a connection state change
 
@@ -932,7 +954,7 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 
 			if (!self->connected) {
 				self->connected = TRUE;
-				g_debug("ccchh-dooris-widget: new connection state: online");
+				g_debug(WIDGET_NAME": new connection state: online");
 
 				// start timer
 				start_update_timer(self);
@@ -949,14 +971,14 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 					!strcmp(iap_id, self->disconnecting))
 			{
 
-				g_debug("ccchh-dooris-widget: ignoring offline event from disconnecting IAP");
+				g_debug(WIDGET_NAME": ignoring offline event from disconnecting IAP");
 
 			} else {
 
 				// we are offline now
 
 				self->connected = FALSE;
-				g_debug("ccchh-dooris-widget: new connection state: offline");
+				g_debug(WIDGET_NAME": new connection state: offline");
 
 				// don't stop timer here
 				// it will deactivate itsef if !connected
@@ -989,12 +1011,12 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 	g_assert (self->settings_window);
 	g_assert (self->settings_window == GTK_WIDGET (dialog));
   
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_settings_dialog_response()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_settings_dialog_response()");
 
 	// only use new settings if user pressed the OK button
 	// TODO: add reset button to restore defaults
 	if (response_id == GTK_RESPONSE_ACCEPT) {
-		g_debug("ccchh-dooris-widget: response accept");
+		g_debug(WIDGET_NAME": response accept");
 
 		// status URL
 		if (self->update_url) {
@@ -1004,13 +1026,13 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 
 		// try to build a valid URI from user input
 		self->update_url = gnome_vfs_make_uri_from_input(gtk_entry_get_text(GTK_ENTRY (self->url_entry)));
-		g_debug("ccchh-dooris-widget: new URL: %s\n", self->update_url);
+		g_debug(WIDGET_NAME": new URL: %s\n", self->update_url);
 
 
 		// update interval
 		const gchar *choice = hildon_button_get_value(HILDON_BUTTON (self->update_picker));
 		self->update_interval = CLAMP(g_ascii_strtod (choice, NULL), UPDATE_INTERVAL_MIN, UPDATE_INTERVAL_MAX);
-		g_debug("ccchh-dooris-widget: new update interval: %ld\n", (long)self->update_interval);
+		g_debug(WIDGET_NAME": new update interval: %ld\n", (long)self->update_interval);
 
 		// if a timer was running, reset it
 		if (stop_update_timer(self)) {
@@ -1020,9 +1042,9 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 		// banner notifications
 		self->notify_enabled = hildon_check_button_get_active(HILDON_CHECK_BUTTON(self->notify_button));
 		if (self->notify_enabled) {
-			g_debug("ccchh-dooris-widget: notification enabled");
+			g_debug(WIDGET_NAME": notification enabled");
 		} else {
-			g_debug("ccchh-dooris-widget: notification disabled");
+			g_debug(WIDGET_NAME": notification disabled");
 		}
 
 		// monitor internet connection state, only update if online
@@ -1046,9 +1068,9 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 		// button forces internet connection
 		self->force_connection = hildon_check_button_get_active(HILDON_CHECK_BUTTON(self->connforce_button));
 		if (self->force_connection) {
-			g_debug("ccchh-dooris-widget: button forces connection");
+			g_debug(WIDGET_NAME": button forces connection");
 		} else {
-			g_debug("ccchh-dooris-widget: button does not force connection");
+			g_debug(WIDGET_NAME": button does not force connection");
 		}
 
 		save_settings(self);
@@ -1085,7 +1107,7 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
  
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_show_settings()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_show_settings()");
 
 	// could this be called when the settings window is already open?
 	if (!self->settings_window) {
@@ -1123,16 +1145,35 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 		hbox = gtk_hbox_new (FALSE, HILDON_MARGIN_DEFAULT);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
+		gint selidx = 0;
+
 		// predefined choices for update interval selector
 		HildonTouchSelector *selector = HILDON_TOUCH_SELECTOR (hildon_touch_selector_entry_new_text());
 		hildon_touch_selector_append_text (selector, "5");
+		if (!selidx && self->update_interval <= 5)
+			selidx = 1;
 		hildon_touch_selector_append_text (selector, "10");
+		if (!selidx && self->update_interval <= 10)
+			selidx = 2;
 		hildon_touch_selector_append_text (selector, "15");
+		if (!selidx && self->update_interval <= 15)
+			selidx = 3;
 		hildon_touch_selector_append_text (selector, "20");
+		if (!selidx && self->update_interval <= 20)
+			selidx = 4;
 		hildon_touch_selector_append_text (selector, "25");
+		if (!selidx && self->update_interval <= 25)
+			selidx = 5;
 		hildon_touch_selector_append_text (selector, "30");
+		if (!selidx && self->update_interval <= 30)
+			selidx = 6;
 		hildon_touch_selector_append_text (selector, "45");
+		if (!selidx && self->update_interval <= 45)
+			selidx = 7;
 		hildon_touch_selector_append_text (selector, "60");
+		if (!selidx && self->update_interval <= 60)
+			selidx = 8;
+		hildon_touch_selector_set_active (selector, 0, selidx-1);
 
 		// update interval
 		self->update_picker = hildon_picker_button_new (HILDON_SIZE_FINGER_HEIGHT,
@@ -1181,9 +1222,6 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 	// set current values
 	gtk_entry_set_text(GTK_ENTRY(self->url_entry), self->update_url);
 
-	// no default selection
-	// TODO: find the selector nearest to the current value and activate it
-	hildon_picker_button_set_active (HILDON_PICKER_BUTTON (self->update_picker), -1);
 	char *value_text = g_strdup_printf ("%d", self->update_interval);
 	hildon_button_set_value(HILDON_BUTTON (self->update_picker), value_text);
 	g_free(value_text);
@@ -1201,7 +1239,7 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 static void
 ccchh_dooris_desktop_widget_realize (GtkWidget *widget)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_realize()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_realize()");
 
 	/* Use An RGBA colormap rather than RGB, 
 	 * so we can use transparency in our expose_event() implementation.
@@ -1223,7 +1261,7 @@ ccchh_dooris_desktop_widget_dispose (GObject *object)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (object);
  
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_dispose()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_dispose()");
 
 	// remove settings window if it is still open
 	if (self->settings_window) {
@@ -1242,7 +1280,7 @@ ccchh_dooris_desktop_widget_finalize (GObject *object)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (object);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_finalize()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_finalize()");
  
 	stop_update_timer(self);
   
@@ -1303,7 +1341,7 @@ ccchh_dooris_desktop_widget_class_init (CCCHHDoorIsDesktopWidgetClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_init()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_class_init()");
 
 	object_class->dispose = ccchh_dooris_desktop_widget_dispose;
 	object_class->finalize = ccchh_dooris_desktop_widget_finalize;
@@ -1316,20 +1354,20 @@ ccchh_dooris_desktop_widget_class_init (CCCHHDoorIsDesktopWidgetClass *klass)
 static void
 ccchh_dooris_desktop_widget_class_finalize (CCCHHDoorIsDesktopWidgetClass *klass G_GNUC_UNUSED)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_finalize()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_class_finalize()");
 }
 
 
 static void
 ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_init()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_init()");
 
 /*
 	// initialize GnomeVFS library
 	if (!gnome_vfs_init()) {
 		// FIXME: crashes the whole desktop process
-		g_error("ccchh-dooris-widget: could not initialize GnomeVFS library");
+		g_error(WIDGET_NAME": could not initialize GnomeVFS library");
 		abort();
 	}
 */
@@ -1416,7 +1454,7 @@ ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 		self->connected = TRUE;
 		start_update_timer(self);
 	}
-	g_debug("ccchh-dooris-widget: initial URL: %s\n", self->update_url);
+	g_debug(WIDGET_NAME": initial URL: %s\n", self->update_url);
 }
 
 
@@ -1424,6 +1462,6 @@ ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 CCCHHDoorIsDesktopWidget*
 ccchh_dooris_desktop_widget_new (void)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_new()");
+	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_new()");
 	return g_object_new (TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, NULL);
 }
